@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -39,6 +39,7 @@ from ..document import Document
 from ..resources import DEFAULT_SERVER_HTTP_URL, _SessionCoordinates
 from ..util.browser import NEW_PARAM
 from ..util.token import generate_jwt_token, generate_session_id
+from .states import ErrorReason
 from .util import server_url_for_websocket_url, websocket_url_for_server_url
 
 #-----------------------------------------------------------------------------
@@ -60,7 +61,7 @@ __all__ = (
 # General API
 #-----------------------------------------------------------------------------
 
-def pull_session(session_id=None, url='default', io_loop=None, arguments=None):
+def pull_session(session_id=None, url='default', io_loop=None, arguments=None, max_message_size=20*1024*1024):
     ''' Create a session by loading the current server-side document.
 
     ``session.document`` will be a fresh document loaded from
@@ -108,6 +109,10 @@ def pull_session(session_id=None, url='default', io_loop=None, arguments=None):
             If ``session_id`` is not None, or a session with ``session_id``
             already exists, these arguments will have no effect.
 
+        max_message_size (int, optional) :
+            Configure the Tornado max websocket message size.
+            (default: 20 MB)
+
     Returns:
         ClientSession :
             A new ``ClientSession`` connected to the server
@@ -115,11 +120,12 @@ def pull_session(session_id=None, url='default', io_loop=None, arguments=None):
     '''
 
     coords = _SessionCoordinates(session_id=session_id, url=url)
-    session = ClientSession(session_id=session_id, websocket_url=websocket_url_for_server_url(coords.url), io_loop=io_loop, arguments=arguments)
+    session = ClientSession(
+        session_id=session_id, websocket_url=websocket_url_for_server_url(coords.url), io_loop=io_loop, arguments=arguments, max_message_size=max_message_size)
     session.pull()
     return session
 
-def push_session(document, session_id=None, url='default', io_loop=None):
+def push_session(document, session_id=None, url='default', io_loop=None, max_message_size=20*1024*1024):
     ''' Create a session by pushing the given document to the server,
     overwriting any existing server-side document.
 
@@ -153,13 +159,17 @@ def push_session(document, session_id=None, url='default', io_loop=None):
         io_loop : (tornado.ioloop.IOLoop, optional)
             The IOLoop to use for the websocket
 
+        max_message_size (int, optional) :
+            Configure the Tornado max websocket message size.
+            (default: 20 MB)
+
     Returns:
         ClientSession
             A new ClientSession connected to the server
 
     '''
     coords = _SessionCoordinates(session_id=session_id, url=url)
-    session = ClientSession(session_id=coords.session_id, websocket_url=websocket_url_for_server_url(coords.url), io_loop=io_loop)
+    session = ClientSession(session_id=coords.session_id, websocket_url=websocket_url_for_server_url(coords.url), io_loop=io_loop, max_message_size=max_message_size)
     session.push(document)
     return session
 
@@ -208,7 +218,7 @@ def show_session(session_id=None, url='default', session=None, browser=None, new
         controller.open(server_url + "?bokeh-session-id=" + quote_plus(session_id),
                         new=NEW_PARAM[new])
 
-class ClientSession(object):
+class ClientSession:
     ''' Represents a websocket connection to a server-side session.
 
     Each server session stores a Document, which is kept in sync with the
@@ -231,7 +241,7 @@ class ClientSession(object):
 
     '''
 
-    def __init__(self, session_id=None, websocket_url=DEFAULT_SERVER_WEBSOCKET_URL, io_loop=None, arguments=None):
+    def __init__(self, session_id=None, websocket_url=DEFAULT_SERVER_WEBSOCKET_URL, io_loop=None, arguments=None, max_message_size=20*1024*1024):
         ''' A connection which attaches to a particular named session on the
         server.
 
@@ -261,12 +271,16 @@ class ClientSession(object):
                 If ``session_id`` is not None, or a session with ``session_id``
                 already exists, these arguments will have no effect.
 
+            max_message_size (int, optional) :
+                Configure the Tornado max websocket message size.
+                (default: 20 MB)
+
         '''
         self._document = None
         self._id = self._ensure_session_id(session_id)
 
         from .connection import ClientConnection
-        self._connection = ClientConnection(session=self, io_loop=io_loop, websocket_url=websocket_url, arguments=arguments)
+        self._connection = ClientConnection(session=self, io_loop=io_loop, websocket_url=websocket_url, arguments=arguments, max_message_size=max_message_size)
 
         from ..server.callbacks import _DocumentCallbackGroup
         self._callbacks = _DocumentCallbackGroup(self._connection.io_loop)
@@ -290,6 +304,22 @@ class ClientSession(object):
         ''' Whether this session is currently connected. '''
         return self._connection.connected
 
+    @property
+    def error_reason(self):
+        return self._connection.error_reason
+
+    @property
+    def error_code(self):
+        return self._connection.error_code
+
+    @property
+    def error_detail(self):
+        return self._connection.error_detail
+
+    @property
+    def url(self):
+        return self._connection.url
+
     @property
     def document(self):
         ''' A :class:`~bokeh.document.Document` that will be kept in sync with
@@ -334,6 +364,23 @@ class ClientSession(object):
         '''
         self._connection.force_roundtrip()
 
+    def check_connection_errors(self):
+        ''' Raises an error, when the connection could not have been
+        established.
+
+        Should be used, after a call to connect.
+
+        Returns:
+            None
+
+        '''
+        if not self.connected:
+            if self.error_reason is ErrorReason.HTTP_ERROR:
+                if self.error_code == 404:
+                    raise OSError(f"Check your application path! The given Path is not valid: {self.url}")
+                raise OSError(f"We received an HTTP-Error. Disconnected with error code: {self.error_code}, given message: {self.error_detail}")
+            raise OSError("We failed to connect to the server (to start the server, try the 'bokeh serve' command)")
+
     def pull(self):
         ''' Pull the server's state and set it as session.document.
 
@@ -344,8 +391,7 @@ class ClientSession(object):
 
         '''
         self.connect()
-        if not self.connected:
-            raise IOError("Cannot pull session document because we failed to connect to the server (to start the server, try the 'bokeh serve' command)")
+        self.check_connection_errors()
 
         if self.document is None:
             doc = Document()
@@ -382,8 +428,7 @@ class ClientSession(object):
                 raise ValueError("Cannot push() a different document from existing session.document")
 
         self.connect()
-        if not self.connected:
-            raise IOError("Cannot push session document because we failed to connect to the server (to start the server, try the 'bokeh serve' command)")
+        self.check_connection_errors()
         self._connection.push_doc(doc)
         if self._document is None:
             self._attach_document(doc)
