@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -12,9 +11,7 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
@@ -24,10 +21,9 @@ log = logging.getLogger(__name__)
 # Standard library imports
 import colorsys
 
-# External imports
-
 # Bokeh imports
 from .color import Color
+from ..util.deprecation import deprecated
 
 #-----------------------------------------------------------------------------
 # Globals and constants
@@ -42,11 +38,15 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 class HSL(Color):
-    ''' Represent colors by specifying their Hue, Saturation, and Value.
+    ''' Represent colors by specifying their Hue, Saturation, and lightness.
 
     Alpha values may also optionally be provided. Otherwise, alpha values
     default to 1.
 
+    .. warning::
+        HSL is deprecated as of Bokeh 2.3.1 and will be removed in a future
+        release. Use RGB or named colors instead.
+
     '''
 
     def __init__(self, h, s, l, a=1.0):
@@ -54,18 +54,19 @@ class HSL(Color):
 
         Args:
             h (int) :
-                The Hue, in [0, 255]
+                The Hue, in [0, 360]
 
-            h (int) :
+            s (int) :
                 The Saturation, in [0, 1]
 
-            h (int) :
-                The Value, in [0, 1]
+            l (int) :
+                The lightness, in [0, 1]
 
             a (float, optional) :
                 An alpha value for this color in [0, 1] (default: 1.0)
 
         '''
+        deprecated((2, 3, 1), "HSL()", "RGB() or named colors")
         self.h = h
         self.s = s
         self.l = l
@@ -75,7 +76,7 @@ class HSL(Color):
         ''' Return a copy of this color value.
 
         Returns:
-            HSL
+            :class:`~bokeh.colors.hsl.HSL`
 
         '''
         return HSL(self.h, self.s, self.l, self.a)
@@ -89,7 +90,7 @@ class HSL(Color):
                 The HSL color to copy.
 
         Returns:
-            HSL
+            :class:`~bokeh.colors.hsl.HSL`
 
         '''
         return value.copy()
@@ -103,7 +104,7 @@ class HSL(Color):
                 The RGB color to convert.
 
         Returns:
-            HSL
+            :class:`~bokeh.colors.hsl.HSL`
 
         '''
         return value.to_hsl()
@@ -124,7 +125,7 @@ class HSL(Color):
         ''' Return a HSL copy for this HSL color.
 
         Returns:
-            HSL
+            :class:`~bokeh.colors.hsl.HSL`
 
         '''
         return self.copy()
@@ -134,7 +135,7 @@ class HSL(Color):
         this HSL color.
 
         Returns:
-            HSL
+            :class:`~bokeh.colors.rgb.RGB`
 
         '''
         from .rgb import RGB # prevent circular import
