@@ -1,15 +1,58 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Models for computing good tick locations on different kinds
 of plots.
 
 '''
-from __future__ import absolute_import
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+import logging # isort:skip
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Bokeh imports
 from ..core.enums import LatLon
 from ..core.has_props import abstract
-from ..core.properties import Enum, Float, Instance, Int, Override, Seq
+from ..core.properties import Auto, Either, Enum, Float, Instance, Int, NonNullable, Nullable, Override, Seq
 from ..core.validation import error
 from ..core.validation.errors import MISSING_MERCATOR_DIMENSION
 from ..model import Model
+from .mappers import ScanningColorMapper
+
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'Ticker',
+    'BinnedTicker',
+    'ContinuousTicker',
+    'FixedTicker',
+    'AdaptiveTicker',
+    'CompositeTicker',
+    'SingleIntervalTicker',
+    'DaysTicker',
+    'MonthsTicker',
+    'YearsTicker',
+    'BasicTicker',
+    'LogTicker',
+    'MercatorTicker',
+    'CategoricalTicker',
+    'DatetimeTicker',
+)
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
 
 @abstract
 class Ticker(Model):
@@ -77,7 +120,7 @@ class AdaptiveTicker(ContinuousTicker):
     The smallest allowable interval between two adjacent ticks.
     """)
 
-    max_interval = Float(help="""
+    max_interval = Nullable(Float, help="""
     The largest allowable interval between two adjacent ticks.
 
     .. note::
@@ -108,7 +151,7 @@ class SingleIntervalTicker(ContinuousTicker):
 
     '''
 
-    interval = Float(help="""
+    interval = NonNullable(Float, help="""
     The interval between adjacent ticks.
     """)
 
@@ -155,7 +198,7 @@ class MercatorTicker(BasicTicker):
 
     '''
 
-    dimension = Enum(LatLon, default=None, help="""
+    dimension = Nullable(Enum(LatLon), help="""
     Specify whether to generate ticks for Latitude or Longitude.
 
     Projected coordinates are not separable, computing Latitude and Longitude
@@ -231,3 +274,27 @@ class DatetimeTicker(CompositeTicker):
 
         YearsTicker(),
     ])
+
+class BinnedTicker(Ticker):
+    """Ticker that aligns ticks exactly at bin boundaries of a scanning color mapper. """
+
+    mapper = Instance(ScanningColorMapper, help="""
+    A scanning color mapper (e.g. ``EqHistColorMapper``) to use.
+    """)
+
+    num_major_ticks = Either(Int, Auto, default=8, help="""
+    The number of major tick positions to show or "auto" to use the
+    number of bins provided by the mapper.
+    """)
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
