@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -323,6 +323,22 @@ def test_args() -> None:
             type    = int,
         )),
 
+        ('--websocket-compression-level', dict(
+            metavar = 'LEVEL',
+            action  = 'store',
+            help    = "Set the Tornado WebSocket compression_level",
+            default = None,
+            type    = int,
+        )),
+
+        ('--websocket-compression-mem-level', dict(
+            metavar = 'LEVEL',
+            action  = 'store',
+            help    = "Set the Tornado WebSocket compression mem_level",
+            default = None,
+            type    = int,
+        )),
+
         ('--glob', dict(
             action='store_true',
             help='Process all filename arguments as globs',
@@ -393,8 +409,7 @@ def test_no_glob_by_default_on_filename_if_wildcard_in_quotes() -> None:
 
 
 # http://eyalarubas.com/python-subproc-nonblock.html
-class NBSR(object):
-
+class NBSR:
     def __init__(self, stream):
         '''
         stream: the stream to read from.
