@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -51,12 +51,11 @@ class Test_Instance:
 
     def test_valid(self) -> None:
         prop = bcpi.Instance(_TestModel)
-
-        assert prop.is_valid(None)
         assert prop.is_valid(_TestModel())
 
     def test_invalid(self) -> None:
         prop = bcpi.Instance(_TestModel)
+        assert not prop.is_valid(None)
         assert not prop.is_valid(False)
         assert not prop.is_valid(True)
         assert not prop.is_valid(0)
