@@ -27,6 +27,7 @@ from _util_document import (
     ModelWithSpecInTestDocument,
     SomeModelInTestDocument,
 )
+from bokeh.core.properties import Instance, Int, List, Nullable, Override
 from bokeh.document.events import (
     ColumnsPatchedEvent,
     ColumnsStreamedEvent,
@@ -38,6 +39,7 @@ from bokeh.document.events import (
     TitleChangedEvent,
 )
 from bokeh.io.doc import curdoc
+from bokeh.model import DataModel
 from bokeh.models import ColumnDataSource
 from bokeh.protocol.messages.patch_doc import process_document_events
 from bokeh.util.logconfig import basicConfig
@@ -49,6 +51,18 @@ import bokeh.document.document as document # isort:skip
 # Setup
 #-----------------------------------------------------------------------------
 
+class SomeDataModel(DataModel):
+    prop0 = Int()
+    prop1 = Int(default=111)
+    prop2 = List(Int, default=[1, 2, 3])
+
+class DerivedDataModel(SomeDataModel):
+    prop3 = Int()
+    prop4 = Int(default=112)
+    prop5 = List(Int, default=[1, 2, 3, 4])
+    prop6 = Nullable(Instance(SomeDataModel))
+
+    prop2 = Override(default=119)
 
 #-----------------------------------------------------------------------------
 # General API
@@ -771,6 +785,38 @@ class TestDocument:
         some_root = next(iter(copy.roots))
         assert some_root.child.foo == 44
 
+    def test_serialization_data_models(self) -> None:
+        obj0 = SomeDataModel()
+        obj1 = DerivedDataModel(prop6=obj0)
+
+        doc = document.Document()
+        doc.add_root(obj0)
+        doc.add_root(obj1)
+
+        json = doc.to_json()
+        assert json["defs"] == [{
+            "extends": None,
+            "module": "test_document",
+            "name": "SomeDataModel",
+            "overrides": [],
+            "properties": [
+                {"default": 0, "kind": None, "name": "prop0"},
+                {"default": 111, "kind": None, "name": "prop1"},
+                {"default": [1, 2, 3], "kind": None, "name": "prop2"},
+            ],
+        }, {
+            "extends": {"module": "test_document", "name": "SomeDataModel"},
+            "module": "test_document",
+            "name": "DerivedDataModel",
+            "overrides": [{"default": 119, "name": "prop2"}],
+            "properties": [
+                {"default": 0, "kind": None, "name": "prop3"},
+                {"default": 112, "kind": None, "name": "prop4"},
+                {"default": [1, 2, 3, 4], "kind": None, "name": "prop5"},
+                {"default": None, "kind": None, "name": "prop6"},
+            ],
+        }]
+
     def test_serialization_has_version(self) -> None:
         from bokeh import __version__
         d = document.Document()
