@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -46,6 +46,7 @@ from bokeh.core.enums import (
 )
 from bokeh.core.enums import NamedColor as Color
 from bokeh.core.enums import TextAlign, TextBaseline
+from bokeh.core.property.dataspec import field
 from bokeh.models.glyphs import (
     Asterisk,
     CircleCross,
@@ -84,7 +85,6 @@ from bokeh.models.glyphs import ( # isort:skip
     VBar,
     Wedge)
 
-
 #-----------------------------------------------------------------------------
 # Setup
 #-----------------------------------------------------------------------------
@@ -101,15 +101,16 @@ from bokeh.models.glyphs import ( # isort:skip
 
 def test_AnnularWedge() -> None:
     glyph = AnnularWedge()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.inner_radius is None
-    assert glyph.outer_radius is None
-    assert glyph.start_angle is None
-    assert glyph.end_angle is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.inner_radius == field("inner_radius")
+    assert glyph.outer_radius == field("outer_radius")
+    assert glyph.start_angle == field("start_angle")
+    assert glyph.end_angle == field("end_angle")
     assert glyph.direction == "anticlock"
-    check_fill_properties(glyph)
     check_line_properties(glyph)
+    check_fill_properties(glyph)
+    check_hatch_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "y",
@@ -122,17 +123,18 @@ def test_AnnularWedge() -> None:
         "end_angle",
         "end_angle_units",
         "direction",
-    ], FILL, LINE, GLYPH)
+    ], LINE, FILL, HATCH, GLYPH)
 
 
 def test_Annulus() -> None:
     glyph = Annulus()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.inner_radius is None
-    assert glyph.outer_radius is None
-    check_fill_properties(glyph)
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.inner_radius == field("inner_radius")
+    assert glyph.outer_radius == field("outer_radius")
     check_line_properties(glyph)
+    check_fill_properties(glyph)
+    check_hatch_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "y",
@@ -140,16 +142,16 @@ def test_Annulus() -> None:
         "inner_radius_units",
         "outer_radius",
         "outer_radius_units",
-    ], FILL, LINE, GLYPH)
+    ], LINE, FILL, HATCH, GLYPH)
 
 
 def test_Arc() -> None:
     glyph = Arc()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.radius is None
-    assert glyph.start_angle is None
-    assert glyph.end_angle is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.radius == field("radius")
+    assert glyph.start_angle == field("start_angle")
+    assert glyph.end_angle == field("end_angle")
     assert glyph.direction == "anticlock"
     check_line_properties(glyph)
     check_properties_existence(glyph, [
@@ -167,14 +169,14 @@ def test_Arc() -> None:
 
 def test_Bezier() -> None:
     glyph = Bezier()
-    assert glyph.x0 is None
-    assert glyph.y0 is None
-    assert glyph.x1 is None
-    assert glyph.y1 is None
-    assert glyph.cx0 is None
-    assert glyph.cy0 is None
-    assert glyph.cx1 is None
-    assert glyph.cy1 is None
+    assert glyph.x0 == field("x0")
+    assert glyph.y0 == field("y0")
+    assert glyph.x1 == field("x1")
+    assert glyph.y1 == field("y1")
+    assert glyph.cx0 == field("cx0")
+    assert glyph.cy0 == field("cy0")
+    assert glyph.cx1 == field("cx1")
+    assert glyph.cy1 == field("cy1")
     check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x0",
@@ -190,9 +192,9 @@ def test_Bezier() -> None:
 
 def test_HArea() -> None:
     glyph = HArea()
-    assert glyph.y is None
-    assert glyph.x1 is None
-    assert glyph.x2 is None
+    assert glyph.y == field("y")
+    assert glyph.x1 == field("x1")
+    assert glyph.x2 == field("x2")
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
     check_properties_existence(glyph, [
@@ -204,13 +206,13 @@ def test_HArea() -> None:
 
 def test_HBar() -> None:
     glyph = HBar()
-    assert glyph.y is None
-    assert glyph.height is None
+    assert glyph.y == field("y")
+    assert glyph.height == 1
     assert glyph.left == 0
-    assert glyph.right is None
+    assert glyph.right == field("right")
+    check_line_properties(glyph)
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
-    check_line_properties(glyph)
     check_properties_existence(glyph, [
         "y",
         "height",
@@ -221,11 +223,11 @@ def test_HBar() -> None:
 
 def test_Image() -> None:
     glyph = Image()
-    assert glyph.image is None
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.dw is None
-    assert glyph.dh is None
+    assert glyph.image == field("image")
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.dw == field("dw")
+    assert glyph.dh == field("dh")
     assert glyph.dilate is False
     check_properties_existence(glyph, [
         "image",
@@ -243,11 +245,11 @@ def test_Image() -> None:
 
 def test_ImageRGBA() -> None:
     glyph = ImageRGBA()
-    assert glyph.image is None
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.dw is None
-    assert glyph.dh is None
+    assert glyph.image == field("image")
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.dw == field("dw")
+    assert glyph.dh == field("dh")
     assert glyph.dilate is False
     check_properties_existence(glyph, [
         "image",
@@ -264,9 +266,9 @@ def test_ImageRGBA() -> None:
 
 def test_ImageURL() -> None:
     glyph = ImageURL()
-    assert glyph.url is None
-    assert glyph.x is None
-    assert glyph.y is None
+    assert glyph.url == field("url")
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
     assert glyph.w is None
     assert glyph.h is None
     assert glyph.angle == 0
@@ -295,8 +297,8 @@ def test_ImageURL() -> None:
 
 def test_Line() -> None:
     glyph = Line()
-    assert glyph.x is None
-    assert glyph.y is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
     check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x",
@@ -306,8 +308,8 @@ def test_Line() -> None:
 
 def test_MultiLine() -> None:
     glyph = MultiLine()
-    assert glyph.xs is None
-    assert glyph.ys is None
+    assert glyph.xs == field("xs")
+    assert glyph.ys == field("ys")
     check_line_properties(glyph)
     check_properties_existence(glyph, [
         "xs",
@@ -317,11 +319,11 @@ def test_MultiLine() -> None:
 
 def test_MultiPolygons() -> None:
     glyph = MultiPolygons()
-    assert glyph.xs is None
-    assert glyph.ys is None
+    assert glyph.xs == field("xs")
+    assert glyph.ys == field("ys")
+    check_line_properties(glyph)
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
-    check_line_properties(glyph)
     check_properties_existence(glyph, [
         "xs",
         "ys",
@@ -330,13 +332,14 @@ def test_MultiPolygons() -> None:
 
 def test_Oval() -> None:
     glyph = Oval()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.width is None
-    assert glyph.height is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.width == field("width")
+    assert glyph.height == field("height")
     assert glyph.angle == 0
-    check_fill_properties(glyph)
     check_line_properties(glyph)
+    check_fill_properties(glyph)
+    check_hatch_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "y",
@@ -346,16 +349,16 @@ def test_Oval() -> None:
         "height_units",
         "angle",
         "angle_units",
-    ], FILL, LINE, GLYPH)
+    ], LINE, FILL, HATCH, GLYPH)
 
 
 def test_Patch() -> None:
     glyph = Patch()
-    assert glyph.x is None
-    assert glyph.y is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    check_line_properties(glyph)
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
-    check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "y",
@@ -364,11 +367,11 @@ def test_Patch() -> None:
 
 def test_Patches() -> None:
     glyph = Patches()
-    assert glyph.xs is None
-    assert glyph.ys is None
+    assert glyph.xs == field("xs")
+    assert glyph.ys == field("ys")
+    check_line_properties(glyph)
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
-    check_line_properties(glyph)
     check_properties_existence(glyph, [
         "xs",
         "ys",
@@ -377,13 +380,13 @@ def test_Patches() -> None:
 
 def test_Quad() -> None:
     glyph = Quad()
-    assert glyph.left is None
-    assert glyph.right is None
-    assert glyph.bottom is None
-    assert glyph.top is None
+    assert glyph.left == field("left")
+    assert glyph.right == field("right")
+    assert glyph.bottom == field("bottom")
+    assert glyph.top == field("top")
+    check_line_properties(glyph)
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
-    check_line_properties(glyph)
     check_properties_existence(glyph, [
         "left",
         "right",
@@ -394,12 +397,12 @@ def test_Quad() -> None:
 
 def test_Quadratic() -> None:
     glyph = Quadratic()
-    assert glyph.x0 is None
-    assert glyph.y0 is None
-    assert glyph.x1 is None
-    assert glyph.y1 is None
-    assert glyph.cx is None
-    assert glyph.cy is None
+    assert glyph.x0 == field("x0")
+    assert glyph.y0 == field("y0")
+    assert glyph.x1 == field("x1")
+    assert glyph.y1 == field("y1")
+    assert glyph.cx == field("cx")
+    assert glyph.cy == field("cy")
     check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x0",
@@ -413,10 +416,10 @@ def test_Quadratic() -> None:
 
 def test_Ray() -> None:
     glyph = Ray()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.angle is None
-    assert glyph.length is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.angle == 0
+    assert glyph.length == 0
     check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x",
@@ -430,14 +433,15 @@ def test_Ray() -> None:
 
 def test_Rect() -> None:
     glyph = Rect()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.width is None
-    assert glyph.height is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.width == field("width")
+    assert glyph.height == field("height")
     assert glyph.angle == 0
     assert glyph.dilate is False
-    check_fill_properties(glyph)
     check_line_properties(glyph)
+    check_fill_properties(glyph)
+    check_hatch_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "y",
@@ -448,15 +452,15 @@ def test_Rect() -> None:
         "angle",
         "angle_units",
         "dilate",
-    ], FILL, LINE, GLYPH)
+    ], LINE, FILL, HATCH, GLYPH)
 
 
 def test_Segment() -> None:
     glyph = Segment()
-    assert glyph.x0 is None
-    assert glyph.y0 is None
-    assert glyph.x1 is None
-    assert glyph.y1 is None
+    assert glyph.x0 == field("x0")
+    assert glyph.y0 == field("y0")
+    assert glyph.x1 == field("x1")
+    assert glyph.y1 == field("y1")
     check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x0",
@@ -468,8 +472,8 @@ def test_Segment() -> None:
 
 def test_Step() -> None:
     glyph = Step()
-    assert glyph.x is None
-    assert glyph.y is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
     assert glyph.mode == "before"
     check_line_properties(glyph)
     check_properties_existence(glyph, [
@@ -481,8 +485,8 @@ def test_Step() -> None:
 
 def test_Text() -> None:
     glyph = Text()
-    assert glyph.x is None
-    assert glyph.y is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
     assert glyph.text == "text"
     assert glyph.angle == 0
     check_text_properties(glyph)
@@ -499,9 +503,9 @@ def test_Text() -> None:
 
 def test_VArea() -> None:
     glyph = VArea()
-    assert glyph.x is None
-    assert glyph.y1 is None
-    assert glyph.y2 is None
+    assert glyph.x == field("x")
+    assert glyph.y1 == field("y1")
+    assert glyph.y2 == field("y2")
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
     check_properties_existence(glyph, [
@@ -513,13 +517,13 @@ def test_VArea() -> None:
 
 def test_VBar() -> None:
     glyph = VBar()
-    assert glyph.x is None
-    assert glyph.width is None
-    assert glyph.top is None
+    assert glyph.x == field("x")
+    assert glyph.width == 1
+    assert glyph.top == field("top")
     assert glyph.bottom == 0
+    check_line_properties(glyph)
     check_fill_properties(glyph)
     check_hatch_properties(glyph)
-    check_line_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "width",
@@ -530,14 +534,15 @@ def test_VBar() -> None:
 
 def test_Wedge() -> None:
     glyph = Wedge()
-    assert glyph.x is None
-    assert glyph.y is None
-    assert glyph.radius is None
-    assert glyph.start_angle is None
-    assert glyph.end_angle is None
+    assert glyph.x == field("x")
+    assert glyph.y == field("y")
+    assert glyph.radius == field("radius")
+    assert glyph.start_angle == field("start_angle")
+    assert glyph.end_angle == field("end_angle")
     assert glyph.direction == "anticlock"
-    check_fill_properties(glyph)
     check_line_properties(glyph)
+    check_fill_properties(glyph)
+    check_hatch_properties(glyph)
     check_properties_existence(glyph, [
         "x",
         "y",
@@ -548,124 +553,138 @@ def test_Wedge() -> None:
         "end_angle",
         "end_angle_units",
         "direction",
-    ], FILL, LINE, GLYPH)
+    ], LINE, FILL, HATCH, GLYPH)
 
 
 def test_Asterisk() -> None:
     marker = Asterisk()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_Circle() -> None:
     marker = Circle()
     check_marker_properties(marker)
     assert marker.radius is None
-    check_fill_properties(marker)
     check_line_properties(marker)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
     check_properties_existence(marker, [
         "radius",
         "radius_units",
         "radius_dimension",
-    ], MARKER, FILL, LINE, GLYPH)
+    ], MARKER, LINE, FILL, HATCH, GLYPH)
 
 
 def test_CircleCross() -> None:
     marker = CircleCross()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_CircleX() -> None:
     marker = CircleX()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_Cross() -> None:
     marker = Cross()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_Dash() -> None:
     marker = Dash()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_Diamond() -> None:
     marker = Diamond()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_DiamondCross() -> None:
     marker = DiamondCross()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_InvertedTriangle() -> None:
     marker = InvertedTriangle()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_Square() -> None:
     marker = Square()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_SquareCross() -> None:
     marker = SquareCross()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_SquareX() -> None:
     marker = SquareX()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_Triangle() -> None:
     marker = Triangle()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 
 def test_X() -> None:
     marker = X()
     check_marker_properties(marker)
-    check_fill_properties(marker)
     check_line_properties(marker)
-    check_properties_existence(marker, MARKER, FILL, LINE, GLYPH)
+    check_fill_properties(marker)
+    check_hatch_properties(marker)
+    check_properties_existence(marker, MARKER, LINE, FILL, HATCH, GLYPH, ["marker"])
 
 #-----------------------------------------------------------------------------
 # Dev API
