@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -16,7 +16,7 @@ import pytest ; pytest
 
 # Bokeh imports
 import bokeh.document as document
-from bokeh.core.properties import Instance, Int
+from bokeh.core.properties import Instance, Int, Nullable
 from bokeh.model import Model
 
 # Module under test
@@ -37,7 +37,7 @@ class AnotherModelInTestPullDoc(Model):
 
 class SomeModelInTestPullDoc(Model):
     foo = Int(2)
-    child = Instance(Model)
+    child = Nullable(Instance(Model))
 
 
 class TestPullDocument:
