@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -21,6 +21,7 @@ import logging
 from tornado.websocket import WebSocketClosedError
 
 # Bokeh imports
+from bokeh.server.views.auth_mixin import AuthMixin
 from bokeh.util.logconfig import basicConfig
 
 # Module under test
@@ -38,7 +39,7 @@ basicConfig()
 #-----------------------------------------------------------------------------
 
 async def test_send_message_raises(caplog) -> None:
-    class ExcMessage(object):
+    class ExcMessage:
         def send(self, handler):
             raise WebSocketClosedError()
     assert len(caplog.records) == 0
@@ -49,6 +50,9 @@ async def test_send_message_raises(caplog) -> None:
         assert caplog.text.endswith("Failed sending message as connection was closed\n")
         assert ret is None
 
+def test_uses_auth_mixin() -> None:
+    assert issubclass(WSHandler, AuthMixin)
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
