@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -15,7 +15,7 @@ import pytest ; pytest
 #-----------------------------------------------------------------------------
 
 # Bokeh imports
-from bokeh.core.properties import Any, Dict, Instance, Int, List, String
+from bokeh.core.properties import Any, Dict, Instance, Int, List, Nullable, String
 from bokeh.core.property.wrappers import PropertyValueDict, PropertyValueList
 from bokeh.model import Model
 
@@ -38,7 +38,7 @@ def large_plot(n):
     from bokeh.models import Column, Line
 
     col = Column()
-    objects = set([col])
+    objects = {col}
 
     for i in range(n):
         source = ColumnDataSource(data=dict(x=[0, i + 1], y=[0, i + 1]))
@@ -70,7 +70,7 @@ def large_plot(n):
         col.children.append(plot)
         objects |= set([
             xdr, ydr,
-            xaxis, yaxis,
+            xaxis, xaxis.major_label_policy, yaxis, yaxis.major_label_policy,
             xgrid, ygrid,
             renderer, renderer.view, glyph,
             source, source.selected, source.selection_policy,
@@ -81,8 +81,7 @@ def large_plot(n):
     return col, objects
 
 
-class TestModelCls(object):
-
+class TestModelCls:
     def setup_method(self):
         from bokeh.model import Model
         self.model_cls = Model
@@ -111,20 +110,20 @@ class TestModelCls(object):
             get_class('Imaginary_Class')
 
 class SomeModel(Model):
-    some = Int()
+    some = Int(default=0)
 
 class DeepModel(Model):
-    child = Instance(Model)
+    child = Nullable(Instance(Model))
 
-class TestCollectModels(object):
 
+class TestCollectModels:
     def test_references_large(self) -> None:
         root, objects = large_plot(10)
         assert set(root.references()) == objects
 
     def test_references_deep(self) -> None:
         root = DeepModel()
-        objects = set([root])
+        objects = {root}
         parent = root
         # in a previous implementation, about 400 would blow max
         # recursion depth, so we double that and a little bit,
@@ -141,8 +140,8 @@ class SomeModelToJson(Model):
     foo = Int()
     bar = String()
 
-class TestModel(object):
 
+class TestModel:
     def setup_method(self):
         self.pObjectClass = SomeModel
         self.maxDiff = None
@@ -154,10 +153,25 @@ class TestModel(object):
         testObject2 = self.pObjectClass()
         assert testObject2.id is not None
 
-        assert set(["name", "tags", "js_property_callbacks", "subscribed_events", "js_event_callbacks", "some"]) == testObject.properties()
-        assert dict(name=None, tags=[], js_property_callbacks={}, js_event_callbacks={}, subscribed_events=[], some=None) == \
-            testObject.properties_with_values(include_defaults=True)
-        assert dict() == testObject.properties_with_values(include_defaults=False)
+        assert testObject.properties() == {
+            "name",
+            "tags",
+            "js_property_callbacks",
+            "js_event_callbacks",
+            "subscribed_events",
+            "syncable",
+            "some",
+        }
+        assert testObject.properties_with_values(include_defaults=True) == dict(
+            name=None,
+            tags=[],
+            js_property_callbacks={},
+            js_event_callbacks={},
+            subscribed_events=[],
+            syncable=True,
+            some=0,
+        )
+        assert testObject.properties_with_values(include_defaults=False) == {}
 
     def test_struct(self) -> None:
         testObject = self.pObjectClass(id='test_id')
@@ -218,7 +232,7 @@ class TestModel(object):
         u1, u2, u3, u4, u5 = U(a=1), U(a=2), U(a=3), U(a=4), U(a=5)
         v = V(u1=u1, u2=[u2], u3=(3, u3), u4={"4": u4}, u5={"5": [u5]})
 
-        assert v.references() == set([v, u1, u2, u3, u4, u5])
+        assert v.references() == {v, u1, u2, u3, u4, u5}
 
     def test_to_json(self) -> None:
         child_obj = SomeModelToJson(foo=57, bar="hello")
@@ -234,13 +248,22 @@ class TestModel(object):
             'js_property_callbacks': {},
             "js_event_callbacks": {},
             "subscribed_events": [],
+            "syncable": True,
             "foo": 42,
             "bar": "world",
         }
-        assert ('{"bar":"world",' +
-                '"child":{"id":"%s"},' +
-                '"foo":42,"id":"%s","js_event_callbacks":{},"js_property_callbacks":{},' +
-                '"name":null,"subscribed_events":[],"tags":[]}') % (child_obj.id, obj.id) == json_string
+        assert (
+            '{"bar":"world",' +
+            '"child":{"id":"%s"},' +
+            '"foo":42,' +
+            '"id":"%s",' +
+            '"js_event_callbacks":{},' +
+            '"js_property_callbacks":{},' +
+            '"name":null,' +
+            '"subscribed_events":[],' +
+            '"syncable":true,' +
+            '"tags":[]}'
+        ) % (child_obj.id, obj.id) == json_string
 
     def test_no_units_in_json(self) -> None:
         from bokeh.models import AnnularWedge
@@ -258,7 +281,7 @@ class TestModel(object):
         json = obj.to_json(include_defaults=True)
         assert 'start_angle' in json
         assert 'start_angle_units' not in json
-        assert dict(units='rad', field='fieldname') == json['start_angle']
+        assert dict(field='fieldname') == json['start_angle']
 
     def test_dataspec_value_in_json(self) -> None:
         from bokeh.models import AnnularWedge
@@ -267,7 +290,7 @@ class TestModel(object):
         json = obj.to_json(include_defaults=True)
         assert 'start_angle' in json
         assert 'start_angle_units' not in json
-        assert dict(units='rad', value=60) == json['start_angle']
+        assert dict(value=60) == json['start_angle']
 
     def test_list_default(self) -> None:
         class HasListDefault(Model):
@@ -329,8 +352,8 @@ class TestModel(object):
         # non-default because it's unstable.
         assert 'child' in obj1.properties_with_values(include_defaults=False)
 
-class TestContainerMutation(object):
 
+class TestContainerMutation:
     def _check_mutation(self, obj, attr, mutator, expected_event_old, expected_event_new):
         result = dict(calls=[])
         def record_trigger(attr, old, new_):
